@@ -182,6 +182,11 @@ Kopete::StatusMessage Contact::statusMessage() const
 
 void Contact::setStatusMessage( const Kopete::StatusMessage &statusMessage )
 {
+	bool emitUpdate = true;
+
+	if ( d->statusMessage.title() == statusMessage.title() && d->statusMessage.message() == statusMessage.message() )
+		emitUpdate = false;
+
 	d->statusMessage = statusMessage;
 
 	kDebug(14010) << "Setting up the status title property with this: " << statusMessage.title();
@@ -195,6 +200,9 @@ void Contact::setStatusMessage( const Kopete::StatusMessage &statusMessage )
 		setProperty( Kopete::Global::Properties::self()->statusMessage(), statusMessage.message() );
 	else
 		removeProperty( Kopete::Global::Properties::self()->statusMessage() );
+
+	if ( emitUpdate )
+		emit statusMessageChanged( this );
 }
 
 void Contact::slotAccountIsConnectedChanged()
