@@ -33,6 +33,7 @@
 #include <QGroupBox>
 #include <QProgressBar>
 #include <kopeteview.h>
+#include <kopeteaccount.h>
 
 QList<AuthenticationWizard*> wizardList;
 
@@ -68,6 +69,9 @@ AuthenticationWizard::AuthenticationWizard(QWidget *parent, ConnContext *context
 
 	updateInfoBox();
 
+	if ( session->account()->isBusy() )
+		return;
+
 	show();
 	
 	if ( !session->view()->mainWidget() || !session->view()->mainWidget()->isActiveWindow() ) {
